@@ -3,9 +3,11 @@ __copyright__ = "Copyright 2021, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 import shpc.main.container as container
+from shpc.logger import logger
+import re
 
 
-def main(args, parser, extra):
+def main(args, parser, extra, subparser):
 
     # We currently support GitHub and Docker URIs
     if not re.search("^(gh|docker)", args.uri):
